@@ -5,8 +5,8 @@ kl = sensenet.importers.import_keras_layers()
 from sensenet.accessors import get_image_shape, get_output_exposition
 from sensenet.accessors import get_image_tensor_shape
 from sensenet.constants import IMAGE_PATH, NUMERIC, CATEGORICAL
-from sensenet.layers.construct import layer_sequence, tree_preprocessor
-from sensenet.layers.utils import propagate
+from sensenet.constants import STRING_INPUTS, NUMERIC_INPUTS, PIXEL_INPUTS
+from sensenet.layers.construct import feed_through, tree_preprocessor
 from sensenet.load import load_points
 from sensenet.models.settings import ensure_settings
 from sensenet.preprocess.preprocessor import Preprocessor
@@ -16,24 +16,31 @@ def instantiate_inputs(model, settings):
     ptypes = [p['type'] for p in preprocessors]
 
     ncols = len(preprocessors)
-    nstrings = ptypes.count(IMAGE_PATH) + ptypes.count(CATEGORICAL)
+    nstrings = ptypes.count(IMAGE_PATH)
 
     if ncols == 1 and settings.input_image_format == 'pixel_values':
         assert ptypes[0] == IMAGE_PATH
         image_shape = get_image_tensor_shape(settings)
-        return kl.Input(image_shape, dtype=tf.float32, name='image')
+
+        return kl.Input(image_shape,
+                        dtype=tf.float32,
+                        name=PIXEL_INPUTS)
     else:
         return {
-            'numeric': kl.Input((ncols,), dtype=tf.float32, name='numeric'),
-            'string': kl.Input((nstrings,), dtype=tf.string, name='string')
+            NUMERIC_INPUTS: kl.Input((ncols,),
+                                     dtype=tf.float32,
+                                     name=NUMERIC_INPUTS),
+            STRING_INPUTS: kl.Input((nstrings,),
+                                    dtype=tf.string,
+                                    name=STRING_INPUTS)
         }
 
 def apply_layers(model, settings, inputs, treeed_inputs):
     if 'networks' in model:
-        all_layer_sequences = [layer_sequence(net) for net in model['networks']]
+        all_layer_sequences = [net['layers'] for net in model['networks']]
         use_trees = [net.get('trees', False) for net in model['networks']]
     elif model['layers']:
-        all_layer_sequences = [layer_sequence(model)]
+        all_layer_sequences = [model['layers']]
         use_trees = [treeed_inputs is not None]
     else:
         all_layer_sequences = [[]]
@@ -44,9 +51,9 @@ def apply_layers(model, settings, inputs, treeed_inputs):
 
     for lseq, tree_in in zip(all_layer_sequences, use_trees):
         if tree_in:
-            preds = propagate(lseq, treeed_inputs)
+            preds = feed_through(lseq, treeed_inputs)
         else:
-            preds = propagate(lseq, inputs)
+            preds = feed_through(lseq, inputs)
 
         if outex['type'] == NUMERIC and not settings.regression_normalize:
             preds = preds * outex['stdev'] + outex['mean']
